@@ -1,6 +1,6 @@
-__version__ = "1.0.16"
+__version__ = "1.0.17"
 from janda.pururin import Pururin
 from janda.nhentai import Nhentai
 from janda.hentaifox import Hentaifox
 from janda.hentai2read import Hentai2read
-from janda.utils import *
\ No newline at end of file
+from janda.utils.parser import *
\ No newline at end of file
