@@ -1,6 +1,6 @@
 import requests
 import json
-from .utils.parser import Api
+from .utils.parser import *
 
 BASE_URL = Api()
 
@@ -40,7 +40,7 @@ class Pururin(object):
         api_key : str
             scathach.dev API key (optional)
         """
-        if api_key == '':
+        if api_key is '':
             self.api_key = None
         else:
             self.api_key = api_key
